init

Function init 

pub fn init()
Init the global executor, spawning as many threads as the number or cpus or the value specified by the ASYNC_GLOBAL_EXECUTOR_THREADS environment variable if specified.

Examples

async_global_executor::init();